@@ -8,7 +8,7 @@ pub struct Cli {
     #[arg(value_name = "FILE", default_value = ".", value_hint = ValueHint::AnyPath)]
     pub inputs: Vec<PathBuf>,
 
-    /// Do not ignore entries starting with .
+    /// Do not ignore entries starting with . .
     #[arg(short, long, overrides_with = "almost_all")]
     pub all: bool,
 
@@ -68,8 +68,8 @@ pub struct Cli {
     #[arg(short, long, conflicts_with_all = ["depth", "recursive"])]
     pub directory_only: bool,
 
-    /// How to display permissions [default: rwx]
-    #[arg(long, value_name = "MODE", value_parser = ["rwx", "octal"])]
+    /// How to display permissions [default: rwx for linux, attributes for windows]
+    #[arg(long, value_name = "MODE", value_parser = ["rwx", "octal", "attributes", "disable"])]
     pub permission: Option<String>,
 
     /// How to display size [default: default]
@@ -80,7 +80,7 @@ pub struct Cli {
     #[arg(long)]
     pub total_size: bool,
 
-    /// How to display date [default: date] [possible values: date, relative, +date-time-format]
+    /// How to display date [default: date] [possible values: date, locale, relative, +date-time-format]
     #[arg(long, value_parser = validate_date_argument)]
     pub date: Option<String>,
 
@@ -176,11 +176,23 @@ pub struct Cli {
     #[arg(long)]
     pub header: bool,
 
+    /// Truncate the user and group names if they exceed a certain number of characters
+    #[arg(long, value_name = "NUM")]
+    pub truncate_owner_after: Option<usize>,
+
+    /// Truncation marker appended to a truncated user or group name
+    #[arg(long, value_name = "STR")]
+    pub truncate_owner_marker: Option<String>,
+
     /// Includes files with the windows system protection flag set.
     /// This is the same as --all on other platforms
     #[arg(long, hide = !cfg!(windows))]
     pub system_protected: bool,
 
+    /// Print entry names without quoting
+    #[arg(short = 'N', long)]
+    pub literal: bool,
+
     /// Print help information
     #[arg(long, action = ArgAction::Help)]
     help: (),
