@@ -1,3 +1,5 @@
+//! This module provides methods to handle the program's config files and
+//! operations related to this.
 use crate::flags::display::Display;
 use crate::flags::icons::{IconOption, IconTheme};
 use crate::flags::layout::Layout;
@@ -6,8 +8,6 @@ use crate::flags::size::SizeFlag;
 use crate::flags::sorting::{DirGrouping, SortColumn};
 use crate::flags::HyperlinkOption;
 use crate::flags::{ColorOption, ThemeOption};
-///! This module provides methods to handle the program's config files and operations related to
-///! this.
 use crate::print_error;
 
 use std::path::{Path, PathBuf};
@@ -17,9 +17,6 @@ use serde::Deserialize;
 use std::fs;
 use std::io;
 
-const CONF_DIR: &str = "lsd";
-const CONF_FILE_NAME: &str = "config.yaml";
-
 /// A struct to hold an optional configuration items, and provides methods
 /// around error handling in a config file.
 #[derive(Eq, PartialEq, Debug, Deserialize)]
@@ -45,6 +42,8 @@ pub struct Config {
     pub symlink_arrow: Option<String>,
     pub hyperlink: Option<HyperlinkOption>,
     pub header: Option<bool>,
+    pub literal: Option<bool>,
+    pub truncate_owner: Option<TruncateOwner>,
 }
 
 #[derive(Eq, PartialEq, Debug, Deserialize)]
@@ -74,6 +73,37 @@ pub struct Sorting {
     pub dir_grouping: Option<DirGrouping>,
 }
 
+#[derive(Eq, PartialEq, Debug, Deserialize)]
+pub struct TruncateOwner {
+    pub after: Option<usize>,
+    pub marker: Option<String>,
+}
+
+/// This expand the `~` in path to HOME dir
+/// returns the origin one if no `~` found;
+/// returns None if error happened when getting home dir
+///
+/// Implementing this to reuse the `dirs` dependency, avoid adding new one
+pub fn expand_home<P: AsRef<Path>>(path: P) -> Option<PathBuf> {
+    let p = path.as_ref();
+    if !p.starts_with("~") {
+        return Some(p.to_path_buf());
+    }
+    if p == Path::new("~") {
+        return dirs::home_dir();
+    }
+    dirs::home_dir().map(|mut h| {
+        if h == Path::new("/") {
+            // Corner case: `h` root directory;
+            // don't prepend extra `/`, just drop the tilde.
+            p.strip_prefix("~").unwrap().to_path_buf()
+        } else {
+            h.push(p.strip_prefix("~/").unwrap());
+            h
+        }
+    })
+}
+
 impl Config {
     /// This constructs a Config struct with all None
     pub fn with_none() -> Self {
@@ -97,6 +127,8 @@ impl Config {
             symlink_arrow: None,
             hyperlink: None,
             header: None,
+            literal: None,
+            truncate_owner: None,
         }
     }
 
@@ -134,61 +166,50 @@ impl Config {
         serde_yaml::from_str::<Self>(yaml)
     }
 
-    /// This provides the path for a configuration file, according to the XDG_BASE_DIRS specification.
-    /// return None if error like PermissionDenied
-    #[cfg(not(windows))]
-    pub fn config_file_path() -> Option<PathBuf> {
+    /// Config paths for non-Windows platforms will be read from
+    /// `$XDG_CONFIG_HOME/lsd` or `$HOME/.config/lsd`
+    /// (usually, those are the same) in that order.
+    /// The default paths for Windows will be read from
+    /// `%APPDATA%\lsd` or `%USERPROFILE%\.config\lsd` in that order.
+    /// This will apply both to the config file and the theme file.
+    pub fn config_paths() -> impl Iterator<Item = PathBuf> {
+        #[cfg(not(windows))]
         use xdg::BaseDirectories;
-        match BaseDirectories::with_prefix(CONF_DIR) {
-            Ok(p) => Some(p.get_config_home()),
-            Err(e) => {
-                print_error!("Can not open config file: {}.", e);
-                None
-            }
-        }
-    }
 
-    /// This provides the path for a configuration file, inside the %APPDATA% directory.
-    /// return None if error like PermissionDenied
-    #[cfg(windows)]
-    pub fn config_file_path() -> Option<PathBuf> {
-        dirs::config_dir().map(|x| x.join(CONF_DIR))
-    }
-
-    /// This expand the `~` in path to HOME dir
-    /// returns the origin one if no `~` found;
-    /// returns None if error happened when getting home dir
-    ///
-    /// Implementing this to reuse the `dirs` dependency, avoid adding new one
-    pub fn expand_home<P: AsRef<Path>>(path: P) -> Option<PathBuf> {
-        let p = path.as_ref();
-        if !p.starts_with("~") {
-            return Some(p.to_path_buf());
-        }
-        if p == Path::new("~") {
-            return dirs::home_dir();
-        }
-        dirs::home_dir().map(|mut h| {
-            if h == Path::new("/") {
-                // Corner case: `h` root directory;
-                // don't prepend extra `/`, just drop the tilde.
-                p.strip_prefix("~").unwrap().to_path_buf()
-            } else {
-                h.push(p.strip_prefix("~/").unwrap());
-                h
-            }
-        })
+        [
+            dirs::home_dir().map(|h| h.join(".config")),
+            dirs::config_dir(),
+            #[cfg(not(windows))]
+            BaseDirectories::with_prefix("")
+                .ok()
+                .map(|p| p.get_config_home()),
+        ]
+        .iter()
+        .filter_map(|p| p.as_ref().map(|p| p.join("lsd")))
+        .collect::<Vec<_>>()
+        .into_iter()
     }
 }
 
 impl Default for Config {
+    /// Try to find either config.yaml or config.yml in the config directories
+    /// and use the first one that is found. If none are found, or the parsing fails,
+    /// use the default from DEFAULT_CONFIG.
     fn default() -> Self {
-        if let Some(p) = Self::config_file_path() {
-            if let Some(c) = Self::from_file(p.join(CONF_FILE_NAME)) {
-                return c;
-            }
-        }
-        Self::from_yaml(DEFAULT_CONFIG).unwrap()
+        Config::config_paths()
+            .find_map(|p| {
+                let yaml = p.join("config.yaml");
+                let yml = p.join("config.yml");
+                if yaml.is_file() {
+                    Config::from_file(yaml)
+                } else if yml.is_file() {
+                    Config::from_file(yml)
+                } else {
+                    None
+                }
+            })
+            .or(Self::from_yaml(DEFAULT_CONFIG).ok())
+            .expect("Failed to read both config file and default config")
     }
 }
 
@@ -231,7 +252,7 @@ color:
 # This specifies the date format for the date column. The freeform format
 # accepts an strftime like string.
 # When "classic" is set, this is set to "date".
-# Possible values: date, relative, +<date_format>
+# Possible values: date, locale, relative, +<date_format>
 # date: date
 
 # == Dereference ==
@@ -289,8 +310,8 @@ size: default
 
 # == Permission ==
 # Specify the format of the permission column.
-# Possible value: rwx, octal
-permission: rwx
+# Possible value: rwx, octal, attributes, disable
+# permission: rwx
 
 # == Sorting ==
 sorting:
@@ -323,6 +344,20 @@ hyperlink: never
 # == Symlink arrow ==
 # Specifies how the symlink arrow display, chars in both ascii and utf8
 symlink-arrow: ⇒
+
+# == Literal ==
+# Whether to print entry names without quoting
+# Possible values: false, true
+literal: false
+
+# == Truncate owner ==
+# How to truncate the username and group name for the file if they exceed a
+# certain number of characters.
+truncate-owner:
+  # Number of characters to keep. By default, no truncation is done (empty value).
+  after:
+  # String to be appended to a name if truncated.
+  marker: ""
 "#;
 
 #[cfg(test)]
@@ -339,7 +374,6 @@ mod tests {
     use crate::flags::color::{ColorOption, ThemeOption};
     use crate::flags::icons::{IconOption, IconTheme};
     use crate::flags::layout::Layout;
-    use crate::flags::permission::PermissionFlag;
     use crate::flags::size::SizeFlag;
     use crate::flags::sorting::{DirGrouping, SortColumn};
     use crate::flags::HyperlinkOption;
@@ -378,7 +412,7 @@ mod tests {
                     depth: None,
                 }),
                 size: Some(SizeFlag::Default),
-                permission: Some(PermissionFlag::Rwx),
+                permission: None,
                 sorting: Some(config_file::Sorting {
                     column: Some(SortColumn::Name),
                     reverse: Some(false),
@@ -389,6 +423,11 @@ mod tests {
                 symlink_arrow: Some("⇒".into()),
                 hyperlink: Some(HyperlinkOption::Never),
                 header: None,
+                literal: Some(false),
+                truncate_owner: Some(config_file::TruncateOwner {
+                    after: None,
+                    marker: Some("".to_string()),
+                }),
             },
             c
         );
