@@ -1,6 +1,8 @@
 use crate::color::Colors;
 use crate::display;
-use crate::flags::{ColorOption, Display, Flags, HyperlinkOption, Layout, SortOrder, ThemeOption};
+use crate::flags::{
+    ColorOption, Display, Flags, HyperlinkOption, Layout, Literal, SortOrder, ThemeOption,
+};
 use crate::git::GitCache;
 use crate::icon::Icons;
 
@@ -42,8 +44,6 @@ impl Core {
         #[cfg(target_os = "windows")]
         let console_color_ok = crossterm::ansi_support::supports_ansi();
 
-        let mut inner_flags = flags.clone();
-
         let color_theme = match (tty_available && console_color_ok, flags.color.when) {
             (_, ColorOption::Never) | (false, ColorOption::Auto) => ThemeOption::NoColor,
             _ => flags.color.theme.clone(),
@@ -64,14 +64,19 @@ impl Core {
 
         let icon_separator = flags.icons.separator.0.clone();
 
+        // The output is not a tty, this means the command is piped. e.g.
+        //
+        // lsd -l | less
+        //
+        // Most of the programs does not handle correctly the ansi colors
+        // or require a raw output (like the `wc` command).
         if !tty_available {
-            // The output is not a tty, this means the command is piped. (ex: lsd -l | less)
-            //
-            // Most of the programs does not handle correctly the ansi colors
-            // or require a raw output (like the `wc` command).
-            inner_flags.layout = Layout::OneLine;
+            // we should not overwrite the tree layout
+            if flags.layout != Layout::Tree {
+                flags.layout = Layout::OneLine;
+            }
 
-            flags.should_quote = false;
+            flags.literal = Literal(true);
         };
 
         let sorters = sort::assemble_sorters(&flags);
@@ -102,15 +107,24 @@ impl Core {
             _ => 1,
         };
 
+        #[cfg(target_os = "windows")]
+        use crate::config_file;
+        #[cfg(target_os = "windows")]
+        let paths: Vec<PathBuf> = paths
+            .into_iter()
+            .filter_map(config_file::expand_home)
+            .collect();
+
         for path in paths {
-            let mut meta = match Meta::from_path(&path, self.flags.dereference.0) {
-                Ok(meta) => meta,
-                Err(err) => {
-                    print_error!("{}: {}.", path.display(), err);
-                    exit_code.set_if_greater(ExitCode::MajorIssue);
-                    continue;
-                }
-            };
+            let mut meta =
+                match Meta::from_path(&path, self.flags.dereference.0, self.flags.permission) {
+                    Ok(meta) => meta,
+                    Err(err) => {
+                        print_error!("{}: {}.", path.display(), err);
+                        exit_code.set_if_greater(ExitCode::MajorIssue);
+                        continue;
+                    }
+                };
 
             let cache = if self.flags.blocks.0.contains(&Block::GitStatus) {
                 Some(GitCache::new(&path))
