@@ -7,11 +7,14 @@ mod inode;
 mod links;
 mod locale;
 pub mod name;
-mod owner;
+pub mod owner;
 mod permissions;
+mod permissions_or_attributes;
 mod size;
 mod symlink;
 
+#[cfg(windows)]
+mod windows_attributes;
 #[cfg(windows)]
 mod windows_utils;
 
@@ -23,24 +26,26 @@ pub use self::indicator::Indicator;
 pub use self::inode::INode;
 pub use self::links::Links;
 pub use self::name::Name;
-pub use self::owner::Owner;
+pub use self::owner::{Cache as OwnerCache, Owner};
 pub use self::permissions::Permissions;
+use self::permissions_or_attributes::PermissionsOrAttributes;
 pub use self::size::Size;
 pub use self::symlink::SymLink;
-pub use crate::icon::Icons;
 
-use crate::flags::{Display, Flags, Layout};
+use crate::flags::{Display, Flags, Layout, PermissionFlag};
 use crate::{print_error, ExitCode};
 
 use crate::git::GitCache;
 use std::io::{self, Error, ErrorKind};
 use std::path::{Component, Path, PathBuf};
 
+#[cfg(windows)]
+use self::windows_attributes::get_attributes;
 #[derive(Clone, Debug)]
 pub struct Meta {
     pub name: Name,
     pub path: PathBuf,
-    pub permissions: Option<Permissions>,
+    pub permissions_or_attributes: Option<PermissionsOrAttributes>,
     pub date: Option<Date>,
     pub owner: Option<Owner>,
     pub file_type: FileType,
@@ -72,7 +77,7 @@ impl Meta {
         match self.file_type {
             FileType::Directory { .. } => (),
             FileType::SymLink { is_dir: true } => {
-                if flags.layout == Layout::OneLine {
+                if flags.blocks.0.len() > 1 {
                     return Ok((None, ExitCode::OK));
                 }
             }
@@ -93,11 +98,14 @@ impl Meta {
             && flags.layout != Layout::Tree
         {
             let mut current_meta = self.clone();
-            current_meta.name.name = ".".to_owned();
+            ".".clone_into(&mut current_meta.name.name);
 
-            let mut parent_meta =
-                Self::from_path(&self.path.join(Component::ParentDir), flags.dereference.0)?;
-            parent_meta.name.name = "..".to_owned();
+            let mut parent_meta = Self::from_path(
+                &self.path.join(Component::ParentDir),
+                flags.dereference.0,
+                flags.permission,
+            )?;
+            "..".clone_into(&mut parent_meta.name.name);
 
             current_meta.git_status = cache.and_then(|cache| cache.get(&current_meta.path, true));
             parent_meta.git_status = cache.and_then(|cache| cache.get(&parent_meta.path, true));
@@ -139,7 +147,8 @@ impl Meta {
                 _ => {}
             }
 
-            let mut entry_meta = match Self::from_path(&path, flags.dereference.0) {
+            let mut entry_meta = match Self::from_path(&path, flags.dereference.0, flags.permission)
+            {
                 Ok(res) => res,
                 Err(err) => {
                     print_error!("{}: {}.", path.display(), err);
@@ -244,7 +253,11 @@ impl Meta {
         }
     }
 
-    pub fn from_path(path: &Path, dereference: bool) -> io::Result<Self> {
+    pub fn from_path(
+        path: &Path,
+        dereference: bool,
+        permission_flag: PermissionFlag,
+    ) -> io::Result<Self> {
         let mut metadata = path.symlink_metadata()?;
         let mut symlink_meta = None;
         let mut broken_link = false;
@@ -262,40 +275,73 @@ impl Meta {
                     // path.symlink_metadata would have errored out
                     if dereference {
                         broken_link = true;
-                        eprintln!("lsd: {}: {}\n", path.to_str().unwrap_or(""), e);
+                        eprintln!("lsd: {}: {}", path.to_str().unwrap_or(""), e);
                     }
                 }
             }
         }
 
         #[cfg(unix)]
-        let owner = Owner::from(&metadata);
+        let (owner, permissions) = match permission_flag {
+            PermissionFlag::Disable => (None, None),
+            _ => (
+                Some(Owner::from(&metadata)),
+                Some(Permissions::from(&metadata)),
+            ),
+        };
         #[cfg(unix)]
-        let permissions = Permissions::from(&metadata);
+        let permissions_or_attributes = permissions.map(PermissionsOrAttributes::Permissions);
 
         #[cfg(windows)]
-        let (owner, permissions) = windows_utils::get_file_data(path)?;
+        let (owner, permissions_or_attributes) = match permission_flag {
+            PermissionFlag::Disable => (None, None),
+            PermissionFlag::Attributes => (
+                None,
+                Some(PermissionsOrAttributes::WindowsAttributes(get_attributes(
+                    &metadata,
+                ))),
+            ),
+            _ => match windows_utils::get_file_data(path) {
+                Ok((owner, permissions)) => (
+                    Some(owner),
+                    Some(PermissionsOrAttributes::Permissions(permissions)),
+                ),
+                Err(e) => {
+                    eprintln!(
+                        "lsd: {}: {}(Hint: Consider using `--permission disable`.)",
+                        path.to_str().unwrap_or(""),
+                        e
+                    );
+                    (None, None)
+                }
+            },
+        };
 
         #[cfg(not(windows))]
-        let file_type = FileType::new(&metadata, symlink_meta.as_ref(), &permissions);
+        let file_type = FileType::new(
+            &metadata,
+            symlink_meta.as_ref(),
+            &permissions.unwrap_or_default(),
+        );
 
         #[cfg(windows)]
         let file_type = FileType::new(&metadata, symlink_meta.as_ref(), path);
 
         let name = Name::new(path, file_type);
 
-        let (inode, links, size, date, owner, permissions, access_control) = match broken_link {
-            true => (None, None, None, None, None, None, None),
-            false => (
-                Some(INode::from(&metadata)),
-                Some(Links::from(&metadata)),
-                Some(Size::from(&metadata)),
-                Some(Date::from(&metadata)),
-                Some(owner),
-                Some(permissions),
-                Some(AccessControl::for_path(path)),
-            ),
-        };
+        let (inode, links, size, date, owner, permissions_or_attributes, access_control) =
+            match broken_link {
+                true => (None, None, None, None, None, None, None),
+                false => (
+                    Some(INode::from(&metadata)),
+                    Some(Links::from(&metadata)),
+                    Some(Size::from(&metadata)),
+                    Some(Date::from(&metadata)),
+                    Some(owner),
+                    Some(permissions_or_attributes),
+                    Some(AccessControl::for_path(path)),
+                ),
+            };
 
         Ok(Self {
             inode,
@@ -305,8 +351,8 @@ impl Meta {
             size,
             date,
             indicator: Indicator::from(file_type),
-            owner,
-            permissions,
+            owner: owner.unwrap_or_default(),
+            permissions_or_attributes: permissions_or_attributes.unwrap_or_default(),
             name,
             file_type,
             content: None,
@@ -318,6 +364,8 @@ impl Meta {
 
 #[cfg(test)]
 mod tests {
+    use crate::flags::PermissionFlag;
+
     use super::Meta;
     use std::fs::File;
     use tempfile::tempdir;
@@ -326,17 +374,26 @@ mod tests {
     #[test]
     fn test_from_path_path() {
         let dir = assert_fs::TempDir::new().unwrap();
-        let meta = Meta::from_path(dir.path(), false).unwrap();
+        let meta = Meta::from_path(dir.path(), false, PermissionFlag::Rwx).unwrap();
         assert_eq!(meta.path, dir.path())
     }
 
+    #[test]
+    fn test_from_path_disable_permission() {
+        let dir = assert_fs::TempDir::new().unwrap();
+        let meta = Meta::from_path(dir.path(), false, PermissionFlag::Disable).unwrap();
+        assert!(meta.permissions_or_attributes.is_none());
+        assert!(meta.owner.is_none());
+    }
+
     #[test]
     fn test_from_path() {
         let tmp_dir = tempdir().expect("failed to create temp dir");
 
         let path_a = tmp_dir.path().join("aaa.aa");
         File::create(&path_a).expect("failed to create file");
-        let meta_a = Meta::from_path(&path_a, false).expect("failed to get meta");
+        let meta_a =
+            Meta::from_path(&path_a, false, PermissionFlag::Rwx).expect("failed to get meta");
 
         let path_b = tmp_dir.path().join("bbb.bb");
         let path_c = tmp_dir.path().join("ccc.cc");
@@ -348,10 +405,11 @@ mod tests {
         // likely to fail because of permission issue
         // see https://doc.rust-lang.org/std/os/windows/fs/fn.symlink_file.html
         #[cfg(windows)]
-        std::os::windows::fs::symlink_file(&path_c, &path_b)
+        std::os::windows::fs::symlink_file(path_c, &path_b)
             .expect("failed to create broken symlink");
 
-        let meta_b = Meta::from_path(&path_b, true).expect("failed to get meta");
+        let meta_b =
+            Meta::from_path(&path_b, true, PermissionFlag::Rwx).expect("failed to get meta");
 
         assert!(
             meta_a.inode.is_some()
@@ -359,7 +417,7 @@ mod tests {
                 && meta_a.size.is_some()
                 && meta_a.date.is_some()
                 && meta_a.owner.is_some()
-                && meta_a.permissions.is_some()
+                && meta_a.permissions_or_attributes.is_some()
                 && meta_a.access_control.is_some()
         );
 
@@ -369,7 +427,7 @@ mod tests {
                 && meta_b.size.is_none()
                 && meta_b.date.is_none()
                 && meta_b.owner.is_none()
-                && meta_b.permissions.is_none()
+                && meta_b.permissions_or_attributes.is_none()
                 && meta_b.access_control.is_none()
         );
     }
